#
# spec file for package python-opengl-accelerate
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define tarname PyOpenGL-accelerate
%define _version 3.1.6
Name:           python-opengl-accelerate
Version:        %{_version}
Release:        1.10
Summary:        Acceleration for python-opengl
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            http://pyopengl.sourceforge.net
Source0:        %{tarname}-%{_version}.tar.gz
# test files: GitHub repo has no tags, use commit hash
Source1:        https://github.com/mcfletch/pyopengl/raw/c26398b91a/accelerate/tests/test_arraydatatypeaccel.py
Source2:        https://github.com/mcfletch/pyopengl/raw/c26398b91a/accelerate/tests/test_numpyaccel.py
#
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module opengl >= %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module numpy-devel if (%python-base without python36-base)}
Recommends:     python-numpy
Requires:       python-opengl >= %{version}
Provides:       python-PyOpenGL_accelerate = %{version}-%{release}
%python_subpackages

%description
This set of C (Cython) extensions provides acceleration of common
operations for slow points in PyOpenGL 3.x. For code which uses large
arrays extensively speed-up is around 10% compared to unaccelerated
code.

%prep
%setup -q -n %{tarname}-%{_version}

# _service pulldown creates %%{tarname}-%%{_version}/accelerate/<required files>,
# move them to root of build area and remove 'accelerate' directory
# to continue as normal.
mv accelerate/* ./
rmdir accelerate

# Force Cython to rebuild .c files
rm src/*.c

%build
export CFLAGS="%{optflags} -DGLX_GLXEXT_LEGACY"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch %{SOURCE1} %{SOURCE2}

%files %{python_files}
%license license.txt
%doc README.txt
%{python_sitearch}/OpenGL_accelerate/
%{python_sitearch}/PyOpenGL_accelerate-*-py%{python_version}.egg-info

%changelog
* Fri Apr  1 2022 Scott Bradnick <scott.bradnick@suse.com>
- Adding _service file
- Cleaning up Source0 declaration since PyPI doesn't have a tarball
- Updating hash for 'accelerate/test' Source[1,2]
- Adding code to %%prep section to deal w/ how _service pulls down
  files for the gzip'd tarball
* Thu Mar 31 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to 3.1.6
  * Pulled directly from https://github.com/mcfletch/pyopengl since
    pypi.org (via py2pack fetch) doesn't have this version available.
  * Seems that some packages which use PyOpenGL and accelerate have
    a soft requirement that they're the same version.
* Tue Mar 23 2021 Ben Greiner <code@bnavigator.de>
- Don't build the numpy formathandler for python36.
  NumPy is optional and not available for python36 on Tumbleweed.
- Add test files test_arraydatatypeaccel.py and test_numpyaccel.py
* Fri Jul 17 2020 Markus Ebner <info@ebner-markus.de>
- Update to 3.1.5
  * This aligns python3-opengl-accelerate with python3-opengl, which
    is required by some other packages
  * no real changelog
- Drop patch commit1080.patch, included upstream
- Drop shipped pxd files, included upstream (https://github.com/mcfletch/pyopengl/commit/d401885f6a1c61213058a96e050eb45ee6189b7c)
* Mon Aug 19 2019 John Vandenberg <jayvdb@gmail.com>
- Add commit1080.patch to make source compatible with opengl 3.1.3b2
  needed for Python 3.7 compatibility
- Add wrapper.pxd and formathandler.pxd needed to rebuild from source
* Thu Oct 25 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 3.1.3b1:
  * no real changelog
* Mon Jun  5 2017 aloisio@gmx.com
- Update to version 3.1.1a1
- Converted to single-spec
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 3.1.0
  * no changelog
* Thu Apr 18 2013 toddrme2178@gmail.com
- Initial version
